@@ -1,13 +1,14 @@
 #' Determine the basis for a surmise function
 #'
 #' @param x Surmise Function
-#' @param ... Optional/future parameters
 #' @returns Basis
 #'
 #' @family Different representations for knowledge spaces
 #'
+#' @method kmbasis kmsurmisefunction
+#' @rdname kmbasis
 #' @export
-kmbasis.kmsurmisefunction <- function(x, ...) {
+kmbasis.kmsurmisefunction <- function(x) {
   noi <- ncol(x) - 1
   mat <- as.matrix(x[,(2:(noi+1))])
   storage.mode(mat) <- "integer"
